[![@wq/material][logo]][docs]

**@wq/material** provides a complete set of layout, navigation, and form components for use with the [@wq/react] renderer for [@wq/app].  All provided components work in [React] web environments (via [Material UI]), as well as in [React Native] and [Expo] (via [React Native Paper]).  @wq/material provides a consistent API in all three environments, reducing the need for project-specific ".native.js" implementations.

### [Documentation][docs]

[**Installation**][installation]
&bull;
[**API**][api]
&bull;
[**Components**][components]
&bull;
[Icons][icons]
&bull;
[Inputs][inputs]

[logo]: https://wq.io/images/@wq/material.svg
[docs]: https://wq.io/@wq/material
[installation]: https://wq.io/@wq/material#installation
[api]: https://wq.io/@wq/material#api
[components]: https://wq.io/components/
[icons]: https://wq.io/icons
[inputs]: https://wq.io/inputs/

[@wq/app]: https://wq.io/@wq/app
[@wq/react]: https://wq.io/@wq/react

[React]: https://reactjs.org/
[React Native]: https://reactnative.dev/
[Expo]: https://expo.io/
[Material UI]: https://material-ui.com/
[React Native Paper]: https://callstack.github.io/react-native-paper/
